@@ -10,11 +10,14 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
+import os
+
 from botocore import xform_name
+from botocore.docs.bcdoc.restdoc import DocumentStructure
 from botocore.docs.method import get_instance_public_methods
 from botocore.docs.utils import DocumentedShape
 
-from boto3.docs.base import BaseDocumenter
+from boto3.docs.base import NestedDocumenter
 from boto3.docs.method import document_model_driven_resource_method
 from boto3.docs.utils import (
     add_resource_type_overview,
@@ -22,7 +25,7 @@ from boto3.docs.utils import (
 )
 
 
-class CollectionDocumenter(BaseDocumenter):
+class CollectionDocumenter(NestedDocumenter):
     def document_collections(self, section):
         collections = self._resource.meta.resource_model.collections
         collections_list = []
@@ -37,10 +40,28 @@ class CollectionDocumenter(BaseDocumenter):
         )
         self.member_map['collections'] = collections_list
         for collection in collections:
-            collection_section = section.add_new_section(collection.name)
             collections_list.append(collection.name)
+            # Create a new DocumentStructure for each collection and add contents.
+            collection_doc = DocumentStructure(collection.name, target='html')
+            breadcrumb_section = collection_doc.add_new_section('breadcrumb')
+            breadcrumb_section.style.ref(self._resource_class_name, 'index')
+            breadcrumb_section.write(f' / Collection / {collection.name}')
+            collection_doc.add_title_section(collection.name)
+            collection_section = collection_doc.add_new_section(
+                collection.name,
+                context={'qualifier': f'{self.class_name}.'},
+            )
             self._document_collection(collection_section, collection)
 
+            # Write collections in individual/nested files.
+            # Path: <root>/reference/services/<service>/<resource_name>/<collection_name>.rst
+            collections_dir_path = os.path.join(
+                self._root_docs_path,
+                f'{self._service_name}',
+                f'{self._resource_sub_path}',
+            )
+            collection_doc.write_to_file(collections_dir_path, collection.name)
+
     def _document_collection(self, section, collection):
         methods = get_instance_public_methods(
             getattr(self._resource, collection.name)
@@ -73,7 +94,9 @@ class CollectionDocumenter(BaseDocumenter):
 
 
 def document_collection_object(
-    section, collection_model, include_signature=True
+    section,
+    collection_model,
+    include_signature=True,
 ):
     """Documents a collection resource object
 
@@ -85,14 +108,17 @@ def document_collection_object(
         It is useful for generating docstrings.
     """
     if include_signature:
-        section.style.start_sphinx_py_attr(collection_model.name)
+        full_collection_name = (
+            f"{section.context.get('qualifier', '')}{collection_model.name}"
+        )
+        section.style.start_sphinx_py_attr(full_collection_name)
     section.include_doc_string(
-        'A collection of %s resources.' % collection_model.resource.type
+        f'A collection of {collection_model.resource.type} resources.'
     )
     section.include_doc_string(
-        'A %s Collection will include all resources by default, '
-        'and extreme caution should be taken when performing '
-        'actions on all resources.' % collection_model.resource.type
+        f'A {collection_model.resource.type} Collection will include all '
+        f'resources by default, and extreme caution should be taken when '
+        f'performing actions on all resources.'
     )
 
 
@@ -139,12 +165,7 @@ def document_batch_action(
     example_resource_name = xform_name(resource_name)
     if service_model.service_name == resource_name:
         example_resource_name = resource_name
-    example_prefix = '{} = {}.{}.{}'.format(
-        example_return_value,
-        example_resource_name,
-        collection_model.name,
-        batch_action_model.name,
-    )
+    example_prefix = f'{example_return_value} = {example_resource_name}.{collection_model.name}.{batch_action_model.name}'
     document_model_driven_resource_method(
         section=section,
         method_name=batch_action_model.name,
@@ -200,56 +221,38 @@ def document_collection_method(
     custom_action_info_dict = {
         'all': {
             'method_description': (
-                'Creates an iterable of all %s resources '
-                'in the collection.' % collection_model.resource.type
-            ),
-            'example_prefix': '{}_iterator = {}.{}.all'.format(
-                xform_name(collection_model.resource.type),
-                example_resource_name,
-                collection_model.name,
+                f'Creates an iterable of all {collection_model.resource.type} '
+                f'resources in the collection.'
             ),
+            'example_prefix': f'{xform_name(collection_model.resource.type)}_iterator = {example_resource_name}.{collection_model.name}.all',
             'exclude_input': underlying_operation_members,
         },
         'filter': {
             'method_description': (
-                'Creates an iterable of all %s resources '
-                'in the collection filtered by kwargs passed to '
-                'method. A %s collection will include all resources by '
-                'default if no filters are provided, and extreme '
-                'caution should be taken when performing actions '
-                'on all resources.'
-                % (
-                    collection_model.resource.type,
-                    collection_model.resource.type,
-                )
-            ),
-            'example_prefix': '{}_iterator = {}.{}.filter'.format(
-                xform_name(collection_model.resource.type),
-                example_resource_name,
-                collection_model.name,
+                f'Creates an iterable of all {collection_model.resource.type} '
+                f'resources in the collection filtered by kwargs passed to '
+                f'method. A {collection_model.resource.type} collection will '
+                f'include all resources by default if no filters are provided, '
+                f'and extreme caution should be taken when performing actions '
+                f'on all resources.'
             ),
+            'example_prefix': f'{xform_name(collection_model.resource.type)}_iterator = {example_resource_name}.{collection_model.name}.filter',
             'exclude_input': get_resource_ignore_params(
                 collection_model.request.params
             ),
         },
         'limit': {
             'method_description': (
-                'Creates an iterable up to a specified amount of '
-                '%s resources in the collection.'
-                % collection_model.resource.type
-            ),
-            'example_prefix': '{}_iterator = {}.{}.limit'.format(
-                xform_name(collection_model.resource.type),
-                example_resource_name,
-                collection_model.name,
+                f'Creates an iterable up to a specified amount of '
+                f'{collection_model.resource.type} resources in the collection.'
             ),
+            'example_prefix': f'{xform_name(collection_model.resource.type)}_iterator = {example_resource_name}.{collection_model.name}.limit',
             'include_input': [
                 DocumentedShape(
                     name='count',
                     type_name='integer',
                     documentation=(
-                        'The limit to the number of resources '
-                        'in the iterable.'
+                        'The limit to the number of resources in the iterable.'
                     ),
                 )
             ],
@@ -257,22 +260,17 @@ def document_collection_method(
         },
         'page_size': {
             'method_description': (
-                'Creates an iterable of all %s resources '
-                'in the collection, but limits the number of '
-                'items returned by each service call by the specified '
-                'amount.' % collection_model.resource.type
-            ),
-            'example_prefix': '{}_iterator = {}.{}.page_size'.format(
-                xform_name(collection_model.resource.type),
-                example_resource_name,
-                collection_model.name,
+                f'Creates an iterable of all {collection_model.resource.type} '
+                f'resources in the collection, but limits the number of '
+                f'items returned by each service call by the specified amount.'
             ),
+            'example_prefix': f'{xform_name(collection_model.resource.type)}_iterator = {example_resource_name}.{collection_model.name}.page_size',
             'include_input': [
                 DocumentedShape(
                     name='count',
                     type_name='integer',
                     documentation=(
-                        'The number of items returned by each ' 'service call'
+                        'The number of items returned by each service call'
                     ),
                 )
             ],
@@ -288,5 +286,5 @@ def document_collection_method(
             event_emitter=event_emitter,
             resource_action_model=collection_model,
             include_signature=include_signature,
-            **action_info
+            **action_info,
         )
